@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2016 by The BRLTTY Developers.
+ * Copyright (C) 1995-2020 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -11,7 +11,7 @@
  * Foundation; either version 2.1 of the License, or (at your option) any
  * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://brltty.com/
+ * Web Page: http://brltty.app/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -242,7 +242,7 @@ extern "C" {
 #define BRL_CMD_CLIP_SAVE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CLIP_SAVE)
 /** restore clipboard from disk */
 #define BRL_CMD_CLIP_RESTORE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CLIP_RESTORE)
-/** set braille input mode dots/text */
+/** set braille typing mode dots/text */
 #define BRL_CMD_BRLUCDOTS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_BRLUCDOTS)
 /** set braille keyboard enabled/disabled */
 #define BRL_CMD_BRLKBD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_BRLKBD)
@@ -274,6 +274,56 @@ extern "C" {
 #define BRL_CMD_NXNBWIN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_NXNBWIN)
 /** set touch navigation on/off */
 #define BRL_CMD_TOUCH_NAV (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TOUCH_NAV)
+/** speak indent of current line */
+#define BRL_CMD_SPEAK_INDENT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_INDENT)
+/** set autospeak indent of current line on/off */
+#define BRL_CMD_ASPK_INDENT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ASPK_INDENT)
+/** refresh braille display */
+#define BRL_CMD_REFRESH (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_REFRESH)
+/** show various device status indicators */
+#define BRL_CMD_INDICATORS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_INDICATORS)
+/** clear the text selection */
+#define BRL_CMD_TXTSEL_CLEAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TXTSEL_CLEAR)
+/** select all of the text */
+#define BRL_CMD_TXTSEL_ALL (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TXTSEL_ALL)
+/** copy selected text to host clipboard */
+#define BRL_CMD_HOST_COPY (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HOST_COPY)
+/** cut selected text to host clipboard */
+#define BRL_CMD_HOST_CUT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HOST_CUT)
+/** insert host clipboard text after screen cursor */
+#define BRL_CMD_HOST_PASTE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HOST_PASTE)
+/** show the window title */
+#define BRL_CMD_GUI_TITLE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_TITLE)
+/** open the braille actions window */
+#define BRL_CMD_GUI_BRL_ACTIONS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_BRL_ACTIONS)
+/** go to the home screen */
+#define BRL_CMD_GUI_HOME (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_HOME)
+/** go back to the previous screen */
+#define BRL_CMD_GUI_BACK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_BACK)
+/** open the device settings window */
+#define BRL_CMD_GUI_DEV_SETTINGS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_DEV_SETTINGS)
+/** open the device options window */
+#define BRL_CMD_GUI_DEV_OPTIONS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_DEV_OPTIONS)
+/** open the application list window */
+#define BRL_CMD_GUI_APP_LIST (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_APP_LIST)
+/** open the application-specific menu */
+#define BRL_CMD_GUI_APP_MENU (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_APP_MENU)
+/** open the application alerts window */
+#define BRL_CMD_GUI_APP_ALERTS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_APP_ALERTS)
+/** return to the active screen area */
+#define BRL_CMD_GUI_AREA_ACTV (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_AREA_ACTV)
+/** switch to the previous screen area */
+#define BRL_CMD_GUI_AREA_PREV (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_AREA_PREV)
+/** switch to the next screen area */
+#define BRL_CMD_GUI_AREA_NEXT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_AREA_NEXT)
+/** move to the first item in the screen area */
+#define BRL_CMD_GUI_ITEM_FRST (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_ITEM_FRST)
+/** move to the previous item in the screen area */
+#define BRL_CMD_GUI_ITEM_PREV (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_ITEM_PREV)
+/** move to the next item in the screen area */
+#define BRL_CMD_GUI_ITEM_NEXT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_ITEM_NEXT)
+/** move to the last item in the screen area */
+#define BRL_CMD_GUI_ITEM_LAST (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_ITEM_LAST)
 /** bring screen cursor to character */
 #define BRL_BLK_ROUTE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ROUTE)
 /** start new clipboard at character */
@@ -292,7 +342,7 @@ extern "C" {
 #define BRL_BLK_COPY_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_COPY_LINE)
 /** deprecated definition of COPY_LINE - linear copy to character */
 #define BRL_BLK_CUTLINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CUTLINE)
-/** switch to a specific virtual terminal */
+/** switch to specific virtual terminal */
 #define BRL_BLK_SWITCHVT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SWITCHVT)
 /** go up to nearest line with less indent than character */
 #define BRL_BLK_PRINDENT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PRINDENT)
@@ -332,7 +382,15 @@ extern "C" {
 #define BRL_BLK_SET_KEYBOARD_TABLE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SET_KEYBOARD_TABLE)
 /** set language profile */
 #define BRL_BLK_SET_LANGUAGE_PROFILE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SET_LANGUAGE_PROFILE)
-/** bind to a specific virtual terminal */
+/** bring screen cursor to line */
+#define BRL_BLK_ROUTE_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ROUTE_LINE)
+/** refresh braille line */
+#define BRL_BLK_REFRESH_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_REFRESH_LINE)
+/** start text selection */
+#define BRL_BLK_TXTSEL_START (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TXTSEL_START)
+/** set text selection */
+#define BRL_BLK_TXTSEL_SET (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TXTSEL_SET)
+/** bind to specific virtual terminal */
 #define BRL_BLK_SELECTVT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SELECTVT)
 /** render an alert */
 #define BRL_BLK_ALERT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ALERT)
