@@ -1,7 +1,7 @@
 /*
  * libbrlapi - A library providing access to braille terminals for applications.
  *
- * Copyright (C) 2002-2019 by
+ * Copyright (C) 2002-2020 by
  *   Samuel Thibault <Samuel.Thibault@ens-lyon.org>
  *   Sébastien Hinderer <Sebastien.Hinderer@ens-lyon.org>
  *
@@ -248,7 +248,7 @@ extern "C" {
 #define BRLAPI_KEY_CMD_CLIP_SAVE (BRLAPI_KEY_CMD(0) + 107)
 /** restore clipboard from disk */
 #define BRLAPI_KEY_CMD_CLIP_RESTORE (BRLAPI_KEY_CMD(0) + 108)
-/** set braille input mode dots/text */
+/** set braille typing mode dots/text */
 #define BRLAPI_KEY_CMD_BRLUCDOTS (BRLAPI_KEY_CMD(0) + 109)
 /** set braille keyboard enabled/disabled */
 #define BRLAPI_KEY_CMD_BRLKBD (BRLAPI_KEY_CMD(0) + 110)
@@ -284,6 +284,52 @@ extern "C" {
 #define BRLAPI_KEY_CMD_SPEAK_INDENT (BRLAPI_KEY_CMD(0) + 125)
 /** set autospeak indent of current line on/off */
 #define BRLAPI_KEY_CMD_ASPK_INDENT (BRLAPI_KEY_CMD(0) + 126)
+/** refresh braille display */
+#define BRLAPI_KEY_CMD_REFRESH (BRLAPI_KEY_CMD(0) + 127)
+/** show various device status indicators */
+#define BRLAPI_KEY_CMD_INDICATORS (BRLAPI_KEY_CMD(0) + 128)
+/** clear the text selection */
+#define BRLAPI_KEY_CMD_TXTSEL_CLEAR (BRLAPI_KEY_CMD(0) + 129)
+/** select all of the text */
+#define BRLAPI_KEY_CMD_TXTSEL_ALL (BRLAPI_KEY_CMD(0) + 130)
+/** copy selected text to host clipboard */
+#define BRLAPI_KEY_CMD_HOST_COPY (BRLAPI_KEY_CMD(0) + 131)
+/** cut selected text to host clipboard */
+#define BRLAPI_KEY_CMD_HOST_CUT (BRLAPI_KEY_CMD(0) + 132)
+/** insert host clipboard text after screen cursor */
+#define BRLAPI_KEY_CMD_HOST_PASTE (BRLAPI_KEY_CMD(0) + 133)
+/** show the window title */
+#define BRLAPI_KEY_CMD_GUI_TITLE (BRLAPI_KEY_CMD(0) + 134)
+/** open the braille actions window */
+#define BRLAPI_KEY_CMD_GUI_BRL_ACTIONS (BRLAPI_KEY_CMD(0) + 135)
+/** go to the home screen */
+#define BRLAPI_KEY_CMD_GUI_HOME (BRLAPI_KEY_CMD(0) + 136)
+/** go back to the previous screen */
+#define BRLAPI_KEY_CMD_GUI_BACK (BRLAPI_KEY_CMD(0) + 137)
+/** open the device settings window */
+#define BRLAPI_KEY_CMD_GUI_DEV_SETTINGS (BRLAPI_KEY_CMD(0) + 138)
+/** open the device options window */
+#define BRLAPI_KEY_CMD_GUI_DEV_OPTIONS (BRLAPI_KEY_CMD(0) + 139)
+/** open the application list window */
+#define BRLAPI_KEY_CMD_GUI_APP_LIST (BRLAPI_KEY_CMD(0) + 140)
+/** open the application-specific menu */
+#define BRLAPI_KEY_CMD_GUI_APP_MENU (BRLAPI_KEY_CMD(0) + 141)
+/** open the application alerts window */
+#define BRLAPI_KEY_CMD_GUI_APP_ALERTS (BRLAPI_KEY_CMD(0) + 142)
+/** return to the active screen area */
+#define BRLAPI_KEY_CMD_GUI_AREA_ACTV (BRLAPI_KEY_CMD(0) + 143)
+/** switch to the previous screen area */
+#define BRLAPI_KEY_CMD_GUI_AREA_PREV (BRLAPI_KEY_CMD(0) + 144)
+/** switch to the next screen area */
+#define BRLAPI_KEY_CMD_GUI_AREA_NEXT (BRLAPI_KEY_CMD(0) + 145)
+/** move to the first item in the screen area */
+#define BRLAPI_KEY_CMD_GUI_ITEM_FRST (BRLAPI_KEY_CMD(0) + 146)
+/** move to the previous item in the screen area */
+#define BRLAPI_KEY_CMD_GUI_ITEM_PREV (BRLAPI_KEY_CMD(0) + 147)
+/** move to the next item in the screen area */
+#define BRLAPI_KEY_CMD_GUI_ITEM_NEXT (BRLAPI_KEY_CMD(0) + 148)
+/** move to the last item in the screen area */
+#define BRLAPI_KEY_CMD_GUI_ITEM_LAST (BRLAPI_KEY_CMD(0) + 149)
 /** bring screen cursor to character */
 #define BRLAPI_KEY_CMD_ROUTE BRLAPI_KEY_CMD(1)
 /** start new clipboard at character */
@@ -342,6 +388,14 @@ extern "C" {
 #define BRLAPI_KEY_CMD_SET_KEYBOARD_TABLE BRLAPI_KEY_CMD(22)
 /** set language profile */
 #define BRLAPI_KEY_CMD_SET_LANGUAGE_PROFILE BRLAPI_KEY_CMD(23)
+/** bring screen cursor to line */
+#define BRLAPI_KEY_CMD_ROUTE_LINE BRLAPI_KEY_CMD(24)
+/** refresh braille line */
+#define BRLAPI_KEY_CMD_REFRESH_LINE BRLAPI_KEY_CMD(25)
+/** start text selection */
+#define BRLAPI_KEY_CMD_TXTSEL_START BRLAPI_KEY_CMD(26)
+/** set text selection */
+#define BRLAPI_KEY_CMD_TXTSEL_SET BRLAPI_KEY_CMD(27)
 /** bind to specific virtual terminal */
 #define BRLAPI_KEY_CMD_SELECTVT BRLAPI_KEY_CMD(30)
 /** render an alert */
