@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2020 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -19,14 +19,16 @@
 #ifndef BRLTTY_INCLUDED_CHARSET
 #define BRLTTY_INCLUDED_CHARSET
 
-#include <stdio.h>
-
+#include "utf8.h"
 #include "lock.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
+extern int isCharsetLatin1 (const char *name);
+extern int isCharsetUTF8 (const char *name);
+
 extern char *getLocaleName (void);
 extern int isPosixLocale (const char *locale);
 
@@ -36,32 +38,15 @@ extern const char *getCharset (void);
 extern const char *getLocaleCharset (void);
 extern const char *getWcharCharset (void);
 
-#define UTF8_SIZE(bits) (((bits) < 8)? 1: (((bits) + 3) / 5))
-#define UTF8_LEN_MAX UTF8_SIZE(32)
-typedef char Utf8Buffer[UTF8_LEN_MAX + 1];
-
 extern size_t convertCharToUtf8 (char c, Utf8Buffer utf8);
 extern int convertUtf8ToChar (const char **utf8, size_t *utfs);
 
-extern size_t convertWcharToUtf8 (wchar_t wc, Utf8Buffer utf8);
-extern wint_t convertUtf8ToWchar (const char **utf8, size_t *utfs);
-
-extern size_t getUtf8Length (const char *utf8);
-extern void convertUtf8ToWchars (const char **utf8, wchar_t **characters, size_t count);
-extern char *makeUtf8FromWchars (const wchar_t *characters, unsigned int count, size_t *length);
-
 extern wint_t convertCharToWchar (char c);
 extern int convertWcharToChar (wchar_t wc);
 
-extern size_t convertTextToWchars (wchar_t *characters, const char *text, size_t size);
-extern size_t getTextLength (const char *text);
-
 extern int lockCharset (LockOptions options);
 extern void unlockCharset (void);
 
-extern int writeUtf8Character (FILE *stream, wchar_t character);
-extern int writeUtf8Characters (FILE *stream, const wchar_t *characters, size_t count);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
