@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2018 by The BRLTTY Developers.
+ * Copyright (C) 1995-2020 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -11,7 +11,7 @@
  * Foundation; either version 2.1 of the License, or (at your option) any
  * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://brltty.com/
+ * Web Page: http://brltty.app/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -32,8 +32,9 @@ typedef enum {
 
 typedef enum {
   tsComputerBraille8,
-  tsContractedBraille,
-  tsComputerBraille6
+  tsContractedBraille6,
+  tsComputerBraille6,
+  tsContractedBraille8,
 } TextStyles;
 
 typedef enum {
@@ -116,9 +117,6 @@ typedef enum {
   ctd2s
 } CursorTrackingDelay;
 
-/*
- * Structure definition for preferences (settings which are saveable).
- */
 typedef struct {
   unsigned char magic[2];
   unsigned char showScreenCursor;
@@ -173,14 +171,17 @@ typedef struct {
   /* No fields above this point should be added, removed, or reordered so that */
   /* backward compatibility with old binary preference files will be retained. */
   /*                                                                           */
-  /* Fields below this point may be modified as needed.                        */
+  /* Fields below this point may be modified as desired.                       */
   /*****************************************************************************/
 
   unsigned char brailleKeyboardEnabled;
-  unsigned char brailleInputMode;
-  unsigned char brailleDisplayOrientation;
+  unsigned char brailleTypingMode;
+  unsigned char brailleQuickSpace;
 
+  unsigned char wordWrap;
   unsigned char capitalizationMode;
+  unsigned char startSelectionWithRoutingKey;
+
   unsigned char speechUppercaseIndicator;
   unsigned char speechWhitespaceIndicator;
 
@@ -190,6 +191,7 @@ typedef struct {
   unsigned char autospeakDeletedCharacters;
   unsigned char autospeakReplacedCharacters;
   unsigned char autospeakCompletedWords;
+  unsigned char autospeakLineIndent;
 
   unsigned char showSpeechCursor;
   unsigned char speechCursorStyle;
@@ -208,9 +210,10 @@ typedef struct {
   unsigned char keyboardLedAlerts;
 
   unsigned char autoreleaseTime;
+  unsigned char onFirstRelease;
   unsigned char touchNavigation;
 
-  unsigned char wordWrap;
+  unsigned char scrollAwareCursorNavigation;
   unsigned char cursorTrackingDelay;
   unsigned char trackScreenScroll;
 
@@ -218,10 +221,16 @@ typedef struct {
   unsigned char showSubmenuSizes;
   unsigned char showAdvancedSubmenus;
   unsigned char showAllItems;
-} PACKED Preferences;
+} PACKED PreferenceSettings;
 
-extern Preferences prefs;		/* current preferences settings */
-#define PREFERENCES_TIME(time) ((time) * 10)
+extern PreferenceSettings prefs;		/* current preferences settings */
+
+#define PREFS_TIME_MULTIPLIER 10
+#define PREFS2MSECS(time) ((time) * PREFS_TIME_MULTIPLIER)
+#define MSECS2PREFS(msecs) (((msecs) + (PREFS_TIME_MULTIPLIER - 1)) / PREFS_TIME_MULTIPLIER)
+
+typedef struct PreferenceDefinitionStruct PreferenceDefinition;
+extern const PreferenceDefinition *findPreference (const char *name);
 
 extern void resetPreferences (void);
 extern int setPreference (char *string);
@@ -231,9 +240,6 @@ extern char *makePreferencesFilePath (const char *name);
 extern int loadPreferencesFile (const char *path);
 extern int savePreferencesFile (const char *path);
 
-typedef struct PreferenceEntryStruct PreferenceEntry;
-extern const PreferenceEntry *findPreferenceEntry (const char *name);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
